@casegroup = 
( 

[ 
[0, 3], [2, 3], [4, 3],
[3, 3], [1, 3], [2, 3],
[4, 3], [0, 3], [1, 3]
],

[
[0, 2], [1, 2],
[2, 2], [1, 2]
]

) ; 
# BETWEEN SQUARE BRACKETS ARE THE BLOCKS OF BLOCK COORDINATE SEARCH. 
# THE FIRST ITEM IN EACH SQUARE BRACKET IS THE POSITION OF THE FIRST ITEM IN THE ACTIVE BLOCK (INDEX FROM 0). 
# THE SECOND ITEM IS THE DIMENSION OF THE ACTIVE BLOCK, IN TERMS OF NUMBER OF PARAMETERS.
# IN THIS EXAMPLE TWO DIFFERENT SEARCH STRUCTURES HAVE BEEN SPECIFIED.
# TWO GROUPS OF SEACHES WILL THEREFORE BE PERFORMED.
