@varn = (
[
[1, 2, 3, 4, 5], [1, 2, 3, 4, 5], [1, 2, 3, 4, 5], 
[2, 4, 5, 1, 3], [2, 4, 5, 1, 3], [2, 4, 5, 1, 3], 
[1, 5, 3, 4, 2], [1, 5, 3, 4, 2], [1, 5, 3, 4, 2]
],
[
[1, 2, 3], [1, 2, 3], 
[2, 3, 1], [2, 3, 1]
]
);
# EACH OF THIS SERIES IS REFERRED TO THE CORRESPONDING BLOCK IN THE SAME POSITION OF THE $casefile.
# THESE SERIES SPECIFY THE ORDER OF PARAMETERS TO BE DECOMPOSED. THE DECOMPOSITION IS THAT SPECIFIED 
# IN THE $casefile. 